import { IServerSideDatasource, LoadSuccessParams, SetFilterModel, SortModelItem, IServerSideGetRowsParams } from '@ag-grid-community/core';
import { Auth, Connect, MetadataDetail, DatasourceOptions } from '@genesislcap/foundation-comms';
import { UUID } from '@genesislcap/foundation-utils';
import { ServerSideDatasourceOptions } from './base.types';
export declare class BaseServerSideDatasource implements IServerSideDatasource {
    auth: Auth;
    connect: Connect;
    uuid: UUID;
    protected rowId: string;
    protected rowData: Map<string, any>;
    reloadResourceDataFunc: (params: DatasourceOptions) => Promise<void>;
    protected resourceName: string;
    resourceParams: any;
    protected resourceIndexes: Map<string, [string]>;
    protected resourceColDefs: MetadataDetail[];
    protected maxRows: number;
    protected maxView: number;
    protected pagination: boolean;
    protected zeroBasedViewNumber: boolean;
    sourceRef: string;
    isNewPageSize: boolean;
    lastSuccessRowData: LoadSuccessParams;
    /**
     * The number of rows in the grid. THIS DO NOT CONSIDER CRITERIA_MATCH scenarios.
     * @internal
     */
    serverRowsCount: number;
    /**
     * The number of rows in the grid. THIS IS A LOCAL COUNT CONSIDERING CONSIDER CRITERIA_MATCH scenarios.
     * @internal
     */
    clientRowsCount: number;
    protected moreRows: boolean;
    protected calculatedRowsCount: number;
    protected currentSequenceId: any;
    protected currentFilterModel: SetFilterModel;
    protected originalCriteriaMatch: string | string[];
    protected currentSortModel: SortModelItem[];
    constructor(options: ServerSideDatasourceOptions);
    getRows(params: IServerSideGetRowsParams<any, any>): void;
    protected setupFilteringAndSorting(params: IServerSideGetRowsParams): Promise<void>;
    destroy?(): void;
    protected refreshDatasource(params: IServerSideGetRowsParams): Promise<void>;
    protected getOrderByAndToBeSortedColIds(map: any, searchValue: any): {
        orderBy: any;
        toBeSorted: any[];
    };
    protected buildCriteriaMatchFromFilters(): string;
    protected criteriaFromFilters(): string[];
    protected getFiltersByType(filterType: string): string[];
    protected getPageNumber(start: number, recordsPerPage: number, totalRecords: number, zeroBasedViewNumber?: boolean): number;
    protected getCorrectRowCount(params: IServerSideGetRowsParams<any, any>): any;
    protected get isNotFirstViewNumber(): boolean;
}
//# sourceMappingURL=server-side.resource-base.d.ts.map